@@ -17,11 +17,11 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 VERSION
 
-Version 0.016
+Version 0.017
 
 =cut
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 my $tools = {
     unix => {
@@ -94,7 +94,8 @@ sub new {
 
 =head2 scan
 
-Attempt to find local system ips, accepts no arguments.
+Attempt to find local system ips, 1 optional argument, of '4' or '6' designating wether
+to look for ipv4 or ipv6 addresses, if left blank search for both.
 
 Returns a list of local ips for the system, will return a blank [] list if nothing found.
 
@@ -102,6 +103,11 @@ Returns a list of local ips for the system, will return a blank [] list if nothi
 
 sub scan {
     my $self = shift;
+    my $type = shift;
+    
+    if (!$type || $type !~ m#^4|6$#) {
+        $type = 0;
+    }
 
     my $return = [];
     my $os = 'unix';
@@ -163,7 +169,7 @@ sub scan {
     
     # Validate all the ips, for speed we will do a silly check first
     foreach my $testIP (@possibleIP) {
-        if ($testIP =~ m#(\d+\.\d+\.\d+\.\d+)#) {
+        if ( ($type == 4 || $type == 0) && $testIP =~ m#(\d+\.\d+\.\d+\.\d+)#) {
             # Copy $1 to $IP because it looks prettier
             my $IP = $1;
             
@@ -175,7 +181,7 @@ sub scan {
             # Push the valid ip into the return space
             push @$return,$IP;
         }
-        elsif ($testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
+        elsif ( ($type == 6 || $type == 0) && $testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
             # Copy $1 to $IP because it looks prettier
             my $IP = $1;
             
